/*
 * QvernoteTypes.h
 *
 *  Created on: May 24, 2010
 *      Author: alexr
 */

#ifndef QVERNOTETYPES_H_
#define QVERNOTETYPES_H_

#include "QvernoteAPI.h"
#include <QListWidgetItem>

using namespace qvernote::api;


#endif /* QVERNOTETYPES_H_ */
